---
title: Theme Guide
published: 2025-01-26
updated: 2025-03-12
tags: ["Blog Theme","Guide"]
pin: 99
lang: en
abbrlink: theme-guide
---

Retypeset is a static blog theme based on the [Astro](https://astro.build/) framework. Inspired by [Typography](https://astro-theme-typography.vercel.app/), Retypeset establishes a new visual standard and reimagines the layout of all pages, creating a reading experience reminiscent of paper books, reviving the beauty of typography. Details in every sight, elegance in every space.

## Theme Configuration

Below is the theme configuration file [src/config.ts](https://github.com/radishzzz/astro-theme-retypeset/blob/master/src/config.ts) for Retypeset.

### Site

```typescript
site: {
  // site title
  title: 'Retypeset'
  // site subtitle
  subtitle: 'Revive the beauty of typography'
  // site description
  description: 'Retypeset is a static blog theme based on the Astro framework. Inspired by Typography...'
  i18nTitle: true // true, false
  // author name
  author: 'radishzz'
  // site url
  url: 'https://retypeset.radishzz.cc'
  // favicon url
  // recommended formats: svg, png or ico
  favicon: '/icon/favicon.svg' // or https://example.com/favicon.svg
}
```

### Color

```typescript
color: {
  // default theme mode
  mode: 'light' // light, dark
  light: {
    // primary color
    // used for title, hover, etc
    // oklch color picker: https://oklch.com/
    primary: 'oklch(25% 0.005 298)'
    // secondary color
    // used for post text
    secondary: 'oklch(40% 0.005 298)'
    // background color
    background: 'oklch(96% 0.005 298)'
  };
  dark: {
    // primary color
    // used for title, hover, etc
    // oklch color picker: https://oklch.com/
    primary: 'oklch(92% 0.005 298)'
    // secondary color
    // used for post text
    secondary: 'oklch(77% 0.005 298)'
    // background color
    background: 'oklch(22% 0.005 298)'
  }
}
```

### Font

```typescript
global: {
  // default language
  locale: 'zh' // zh, zh-tw, ja, en, es, ru
  // more languages
  // not fill in the locale code above again
  moreLocales: ['zh-tw', 'ja', 'en', 'es', 'ru'] // ['zh', 'zh-tw', 'ja', 'en', 'es', 'ru']
  // font styles for post text
  fontStyle: 'sans' // sans, serif
  // date format for posts
  dateFormat: 'YYYY-MM-DD' // YYYY-MM-DD, MM-DD-YYYY, DD-MM-YYYY, MONTH DAY YYYY, DAY MONTH YYYY
  // gap between title and subtitle
  titleGap: 2 // 1, 2, 3
}
```

### Comment

```typescript
comment: {
  // enable comment system
  enabled: true // true, false
  // waline comment system
  // https://waline.js.org/en/
  waline: {
    // server url
    serverURL: 'https://retypeset-comment.radishzz.cc'
    // emoji url
    emoji: [
      'https://unpkg.com/@waline/emojis@1.2.0/tw-emoji',
      // 'https://unpkg.com/@waline/emojis@1.2.0/bmoji',
      // more emojis: https://waline.js.org/en/guide/features/emoji.html
    ]
    // gif search
    search: false // true, false
    // image uploader
    // bug: unable to hide image uploader icon
    imageUploader: false // true, false
  }
}
```

### SEO

```typescript
seo: {
  // @twitter ID
  twitterID: '@radishzz_'
  // site verification
  verification: {
    // google search console
    // https://search.google.com/search-console
    google: 'AUCrz5F1e5qbnmKKDXl2Sf8u6y0kOpEO1wLs6HMMmlM'
    // bing webmaster tools
    // https://www.bing.com/webmasters
    bing: '64708CD514011A7965C84DDE1D169F87'
    // yandex webmaster
    // https://webmaster.yandex.com
    yandex: ''
    // baidu search
    // https://ziyuan.baidu.com
    baidu: ''
  };
  // google analytics
  // https://analytics.google.com
  googleAnalyticsID: ''
  // umami analytics
  // https://cloud.umami.is
  umamiAnalyticsID: '520af332-bfb7-4e7c-9386-5f273ee3d697'
  // follow verification
  // https://follow.is/
  follow: {
    // feed ID
    feedID: ''
    // user ID
    userID: ''
  };
  // apiflash access key
  // automatically generate website screenshots for open graph images
  // get your access key at: https://apiflash.com/
  apiflashKey: ''
}
```

### Footer

```typescript
footer: {
  // social links
  links: [
    {
      name: 'RSS',
      url: '/rss.xml' // rss.xml, atom.xml
    },
    {
      name: 'GitHub',
      url: 'https://github.com/radishzzz/astro-theme-retypeset'
    },
    {
      name: 'Twitter',
      url: 'https://x.com/radishzz_'
    },
    // {
    //   name: 'Email';
    //   url: 'https://example@gmail.com'
    // }
  ];
  // year of website start
  startYear: 2024
}
```

### Preload

```typescript
preload: {
  // link prefetch
  // docs: https://docs.astro.build/en/guides/prefetch/#prefetch-strategies
  linkPrefetch: 'viewport' // hover, tap, viewport, load
  // comment server url
  commentURL: 'https://retypeset-comment.radishzz.cc'
  // image hosting url
  imageHostURL: 'https://image.radishzz.cc'
  // custom google analytics js
  // for users who route analytics javascript to a customized domain
  // See https://gist.github.com/xiaopc/0602f06ca465d76bd9efd3dda9393738
  customGoogleAnalyticsJS: ''
  // custom umami analytics js
  // for users who deploy umami on their own, or route analytics javascript to a customized domain
  // see https://github.com/umami-software/umami/discussions/1026
  customUmamiAnalyticsJS: 'https://js.radishzz.cc/jquery.min.js'
}
```
